Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(171)

Unified Diff: l2tp_manager.h

Issue 6731015: vpn-manager: accept a hostname for remote host (Closed) Base URL: ssh://git@gitrw.chromium.org:9222/vpn-manager.git@master
Patch Set: Created 9 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: l2tp_manager.h
diff --git a/l2tp_manager.h b/l2tp_manager.h
index bb8622830dd8019e62a1194b7a3905a2590e1b1a..b6602f355918eeac63ce89934c7efe0efc8c642e 100644
--- a/l2tp_manager.h
+++ b/l2tp_manager.h
@@ -26,10 +26,10 @@ class L2tpManager : public ServiceManager {
public:
L2tpManager();
// Initialize the object using |remote_address|. Returns false if
// an illegal set of parameters has been given. Has no side effects
// other than setting up the object.
- bool Initialize(const std::string& remote_address);
+ bool Initialize(const std::string& remote_host);
virtual bool Start();
virtual void Stop();
@@ -65,8 +65,8 @@ class L2tpManager : public ServiceManager {
int output_fd_;
// Start time of the l2tp daemon.
base::TimeTicks start_ticks_;
- // Remote address for L2TP connection.
- std::string remote_address_;
+ // Remote host for L2TP connection.
+ std::string remote_host_;
// Last partial line read from output_fd_.
std::string partial_output_line_;
// Path to a file whose existence indicates the ppp device is up.
@@ -26,10 +26,10 @@ class L2tpManager : public ServiceManager {
public:
L2tpManager();
- // Initialize the object using |remote_address|. Returns false if
+ // Initialize the object using |remote_host|. Returns false if
// an illegal set of parameters has been given. Has no side effects
// other than setting up the object.
« ipsec_manager.cc ('K') | « ipsec_manager_test.cc ('k') | l2tp_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698